==> bigloo2.0a.tar.gz: bigloo2.0a/recette/list.scm <==
;*---------------------------------------------------------------------*/
;*   A pratical implementation for the Scheme programming language     */
;*                                                                     */
;*                                    ,--^,                            */
;*                              _ ___/ /|/                             */
;*                          ,;'( )__, ) '                              */
;*                         ;;  //   L__.                               */
;*                         '   \\   /  '                               */
;*                              ^   ^                                  */
;*                                                                     */
;*   Copyright (c) 1992-1999 Manuel Serrano                            */
;*                                                                     */
;*     Bug descriptions, use reports, comments or suggestions are      */
;*     welcome. Send them to                                           */
;*       bigloo-request@kaolin.unice.fr                                */
;*       http://kaolin.unice.fr/bigloo                                 */
;*                                                                     */
;*   This program is free software; you can redistribute it            */
;*   and/or modify it under the terms of the GNU General Public        */
;*   License as published by the Free Software Foundation; either      */
;*   version 2 of the License, or (at your option) any later version.  */
;*                                                                     */
;*   This program is distributed in the hope that it will be useful,   */
;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
;*   GNU General Public License for more details.                      */
;*                                                                     */
;*   You should have received a copy of the GNU General Public         */
;*   License along with this program; if not, write to the Free        */
;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
;*   MA 02111-1307, USA.                                               */
;*---------------------------------------------------------------------*/
;*---------------------------------------------------------------------*/
;*    serrano/prgm/project/bigloo/recette/list.scm                     */
;*                                                                     */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Tue Nov  3 09:21:42 1992                          */
;*    Last change :  Mon Oct 19 08:40:48 1998 (serrano)                */
;*                                                                     */
;*    On test les operations primitives sur les listes                 */
;*---------------------------------------------------------------------*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module list
   (import  (main "main.scm"))
   (include "test.sch")
   (export  (test-list))
   (option  (set! *shared-cnst?* #f)))
 
;*---------------------------------------------------------------------*/
;*    test-list ...                                                    */
;*---------------------------------------------------------------------*/
(define (test-list)
   (test-module "list" "list.scm")
   (test "car" (car (list 1 2 3)) 1)
   (test "cdr" (cdr (list 1 2 3)) '(2 3))
   (test "set-car!" (let ((x (cons 1 2))) (set-car! x 0) x) (cons 0 2))
   (test "set-cdr!" (let ((x (cons 1 2))) (set-cdr! x 0) x) (cons 1 0))
   (test "cons" (cons 1 (cons 2 '())) '(1 2))
   (test "epair" (epair? (econs 1 2 3)) #t)
   (test "epair" (pair? (econs 1 2 3)) #t)
   (test "epair" (cer (econs 1 2 3)) 3)
   (test "epair" (let ((p (econs 1 2 3)))
		    (set-cer! p 4)
		    (cer p))
	 4)
   (test "epair" (car (econs 1 2 3)) 1)
   (test "epair" (cdr (econs 1 2 3)) 2)
   (test "map" (map (lambda (x) (+ 1 x)) '(1 2 3)) '(2 3 4))
   (test "map" (map cons '(1 2 3) '(4 5 6)) '((1 . 4) (2 . 5) (3 . 6)))
   (test "map" (map list '(1 2 3) '(4 5 6)) '((1 4) (2 5) (3 6)))
   (test "map" (map (lambda (a b) (list a b)) '(1 2 3) '(4 5 6))
         '((1 4) (2 5) (3 6)))
   (test "map" (map (lambda (a b c) (list a b c)) '(1 2 3) '(4 5 6) '(7 8 9))
         '((1 4 7) (2 5 8) (3 6 9)))
   (test "map" (map (lambda (x) x) '()) '())
   (test "map" (map car '()) '())
   (test "map" (map car '((1))) '(1))
   (test "for-each" (for-each (lambda (x) x) '()) #t) 
   (test "for-each" (let ((v 0))
		       (for-each (lambda (x) (set! v (+ x v)))
				 '(1 2 3))
		       v)
	 6)
   (test "for-each" (let ((v 0))
		       (for-each (lambda (x y) (set! v (+ y x v)))
				 '(1 2 3) '(4 5 6))
		       v)
	 21)
   (test "for-each" (let ((v 0))
		       (for-each (lambda (x y z) (set! v (+ y x v z)))
				 '(1 2 3) '(4 5 6) '(7 8 9))
		       v)
	 45)
   (test "reverse" (reverse '(1 2 3 4)) '(4 3 2 1))
   (test "reverse!" (reverse! '(1 2 3 4)) '(4 3 2 1))
   (test "list-tail" (list-tail '(1 2 3 4) 2) '(3 4))
   (test "list-ref" (list-ref '(1 2 (3 4) 5) 2) '(3 4))
   (test "assoc" (assoc 1 '((2 3) (4 5))) #f)
   (test "equal" (equal? '(1 2 (3 4 (5) (6 7)) (5 6) "titi"
			     #(1 2 (6 #(6 7)) titi) tutu)
			 '(1 2 (3 4 (5) (6 7)) (5 6) "titi"
			     #(1 2 (6 #(6 7)) titi) tutu))
	 #t)
   (test "equal" (equal? '(1 2 (3 4 (5) (6 7)) (5 6) "titi"
			     #(1 2 (6 #(6 7)) titi) tutu)
			 '(1 2 (3 4 (5) (6 7)) (5 6) "titi"
			     #(1 2 (6 #(6 7)) toto) tutu))
	 #f)
   (test "member" (member '(1 2 3) '((0 1 2) (1 2 3) (4 5 6)))
	 '((1 2 3) (4 5 6)))
   (test "length" (length '(1 2 3)) 3)
   (test "append" (append '(1 2 (3 4)) '((5 6) 7)) '(1 2 (3 4) (5 6) 7))
   (test "list" (list 1 2 3) '(1 2 3))
   (test "list?" (list? '(1 2 . 4)) #f)
   (test "list?" (list? '(1 2 3 4)) #t)
   (test "remq" (let ((x '(1 2 3 4))) (remq 2 x)) '(1 3 4))
   (test "remq!" (let ((x '(1 2 3 4))) (remq! 2 x) x) '(1 3 4))
   (test "remove" (let ((x '(1 2 (3 4) 5))) (remove '(3 4) x)) '(1 2 5))
   (test "remove!" (let ((x '(1 2 (3 4) 5))) (remove! '(3 4) x) x) '(1 2 5))
   (test "memq" (memq 3 '(1 2 3 4 5)) '(3 4 5))
   (test "memq" (memq #\a '(1 2 3 4 5)) #f)
   (test "member" (member '(2 3) '((1 2) (2 3) (3 4) (4 5)))
	 '((2 3) (3 4) (4 5)))
   (test "cons*" (cons* 1 0) '(1 . 0))
   (test "cons*" (cons* (cons* (quote x) 0 (quote ())) (quote ())) '((x 0))))

==> bigloo_2.4b.orig.tar.gz: bigloo2.4b/recette/list.scm <==
;*---------------------------------------------------------------------*/
;*    serrano/prgm/project/bigloo/recette/list.scm                     */
;*                                                                     */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Tue Nov  3 09:21:42 1992                          */
;*    Last change :  Sun Nov 11 08:39:49 2001 (serrano)                */
;*                                                                     */
;*    On test les operations primitives sur les listes                 */
;*---------------------------------------------------------------------*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module list
   (import  (main "main.scm"))
   (include "test.sch")
   (export  (test-list))
   (option  (set! *shared-cnst?* #f)))
 
;*---------------------------------------------------------------------*/
;*    test-list ...                                                    */
;*---------------------------------------------------------------------*/
(define (test-list)
   (test-module "list" "list.scm")
   (test "car" (car (list 1 2 3)) 1)
   (test "cdr" (cdr (list 1 2 3)) '(2 3))
   (test "set-car!" (let ((x (cons 1 2))) (set-car! x 0) x) (cons 0 2))
   (test "set-cdr!" (let ((x (cons 1 2))) (set-cdr! x 0) x) (cons 1 0))
   (test "cons" (cons 1 (cons 2 '())) '(1 2))
   (test "epair" (epair? (econs 1 2 3)) #t)
   (test "epair" (epair? (cons 2 3)) #f)
   (test "epair" (pair? (econs 1 2 3)) #t)
   (test "epair" (cer (econs 1 2 3)) 3)
   (test "epair" (let ((p (econs 1 2 3)))
		    (set-cer! p 4)
		    (cer p))
	 4)
   (test "epair" (car (econs 1 2 3)) 1)
   (test "epair" (cdr (econs 1 2 3)) 2)
   (test "map" (map (lambda (x) (+ 1 x)) '(1 2 3)) '(2 3 4))
   (test "map" (map cons '(1 2 3) '(4 5 6)) '((1 . 4) (2 . 5) (3 . 6)))
   (test "map" (map list '(1 2 3) '(4 5 6)) '((1 4) (2 5) (3 6)))
   (test "map" (map (lambda (a b) (list a b)) '(1 2 3) '(4 5 6))
         '((1 4) (2 5) (3 6)))
   (test "map" (map (lambda (a b c) (list a b c)) '(1 2 3) '(4 5 6) '(7 8 9))
         '((1 4 7) (2 5 8) (3 6 9)))
   (test "map" (map (lambda (x) x) '()) '())
   (test "map" (map car '()) '())
   (test "map" (map car '((1))) '(1))
   (test "for-each" (begin (for-each (lambda (x) x) '()) #t) #t) 
   (test "for-each" (let ((v 0))
		       (for-each (lambda (x) (set! v (+ x v)))
				 '(1 2 3))
		       v)
	 6)
   (test "for-each" (let ((v 0))
		       (for-each (lambda (x y) (set! v (+ y x v)))
				 '(1 2 3) '(4 5 6))
		       v)
	 21)
   (test "for-each" (let ((v 0))
		       (for-each (lambda (x y z) (set! v (+ y x v z)))
				 '(1 2 3) '(4 5 6) '(7 8 9))
		       v)
	 45)
   (test "filter" (filter number? '(1 2 #\a "foo" foo 3)) '(1 2 3))
   (test "filter!" (let ((l (list 1 2 #\a "foo" 'foo 3)))
		      (set! l (filter! number? l))
		      l) '(1 2 3))
   (test "reverse" (reverse '(1 2 3 4)) '(4 3 2 1))
   (test "reverse!" (reverse! '(1 2 3 4)) '(4 3 2 1))
   (test "list-tail" (list-tail '(1 2 3 4) 2) '(3 4))
   (test "list-ref" (list-ref '(1 2 (3 4) 5) 2) '(3 4))
   (test "assoc" (assoc 1 '((2 3) (4 5))) #f)
   (test "equal" (equal? '(1 2 (3 4 (5) (6 7)) (5 6) "titi"
			     #(1 2 (6 #(6 7)) titi) tutu)
			 '(1 2 (3 4 (5) (6 7)) (5 6) "titi"
			     #(1 2 (6 #(6 7)) titi) tutu))
	 #t)
   (test "equal" (equal? '(1 2 (3 4 (5) (6 7)) (5 6) "titi"
			     #(1 2 (6 #(6 7)) titi) tutu)
			 '(1 2 (3 4 (5) (6 7)) (5 6) "titi"
			     #(1 2 (6 #(6 7)) toto) tutu))
	 #f)
   (test "member" (member '(1 2 3) '((0 1 2) (1 2 3) (4 5 6)))
	 '((1 2 3) (4 5 6)))
   (test "length" (length '(1 2 3)) 3)
   (test "append" (append '(1 2 (3 4)) '((5 6) 7)) '(1 2 (3 4) (5 6) 7))
   (test "list" (list 1 2 3) '(1 2 3))
   (test "list?" (list? '(1 2 . 4)) #f)
   (test "list?" (list? '(1 2 3 4)) #t)
   (test "remq" (let ((x '(1 2 3 4))) (remq 2 x)) '(1 3 4))
   (test "remq!" (let ((x '(1 2 3 4))) (remq! 2 x) x) '(1 3 4))
   (test "delete" (let ((x '(1 2 (3 4) 5))) (delete '(3 4) x)) '(1 2 5))
   (test "delete!" (let ((x '(1 2 (3 4) 5))) (delete! '(3 4) x) x) '(1 2 5))
   (test "memq" (memq 3 '(1 2 3 4 5)) '(3 4 5))
   (test "memq" (memq #\a '(1 2 3 4 5)) #f)
   (test "member" (member '(2 3) '((1 2) (2 3) (3 4) (4 5)))
	 '((2 3) (3 4) (4 5)))
   (test "cons*" (cons* 1 0) '(1 . 0))
   (test "cons*" (cons* (cons* (quote x) 0 (quote ())) (quote ())) '((x 0))))
